# Copyright 2015 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Resource definitions for cloud platform apis."""

import enum


BASE_URL = 'https://tpu.googleapis.com/v1/'
DOCS_URL = 'https://cloud.google.com/tpu/'


class Collections(enum.Enum):
  """Collections for all supported apis."""

  PROJECTS = (
      'projects',
      'projects/{projectsId}',
      {},
      [u'projectsId'],
      True
  )
  PROJECTS_LOCATIONS = (
      'projects.locations',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}',
      },
      [u'name'],
      True
  )
  PROJECTS_LOCATIONS_ACCELERATORTYPES = (
      'projects.locations.acceleratorTypes',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/'
              'acceleratorTypes/{acceleratorTypesId}',
      },
      [u'name'],
      True
  )
  PROJECTS_LOCATIONS_NODES = (
      'projects.locations.nodes',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/nodes/{nodesId}',
      },
      [u'name'],
      True
  )
  PROJECTS_LOCATIONS_OPERATIONS = (
      'projects.locations.operations',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/operations/'
              '{operationsId}',
      },
      [u'name'],
      True
  )
  PROJECTS_LOCATIONS_TENSORFLOWVERSIONS = (
      'projects.locations.tensorflowVersions',
      '{+name}',
      {
          '':
              'projects/{projectsId}/locations/{locationsId}/'
              'tensorflowVersions/{tensorflowVersionsId}',
      },
      [u'name'],
      True
  )

  def __init__(self, collection_name, path, flat_paths, params,
               enable_uri_parsing):
    self.collection_name = collection_name
    self.path = path
    self.flat_paths = flat_paths
    self.params = params
    self.enable_uri_parsing = enable_uri_parsing
